API docs for actinia_core and plugins!

OpenAPI is a project used to describe and document RESTful APIs.
actinia is using swagger2, version upgrade is on the agena.

In this repository all API docs should be collected. This way,
the release of the API is not interconnected with the source
code repositories anymore but independent versioning is used.

Currently, the migration is still in progress and the API docs
can be found here or still in the corresponding source code
repository.
